==> pluginbase-1.5.88.jar: org/bimserver/interfaces/objects/SDownloadResult.java <==
package org.bimserver.interfaces.objects;

/******************************************************************************
 * Copyright (C) 2009-2017  BIMserver.org
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see {@literal<http://www.gnu.org/licenses/>}.
 *****************************************************************************/
import javax.activation.DataHandler;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlTransient;

import org.bimserver.shared.meta.SClass;
import org.bimserver.shared.meta.SDataBase;
import org.bimserver.shared.meta.SField;


@XmlRootElement
@XmlSeeAlso(value={SCheckoutResult.class})
public class SDownloadResult implements SDataBase
{
	private long oid = -1;
	private int rid = 0;

	@XmlTransient
	private static SClass sClass;
	private java.lang.String projectName;
	private java.lang.Integer revisionNr;
	private javax.activation.DataHandler file;
	private long serializerOid;

	public long getOid() {
		return this.oid;
	}

	public void setOid(long oid) {
		this.oid = oid;
	}

	public int getRid() {
		return rid;
	}
	
	public void setRid(int rid) {
		this.rid = rid;
	}
	
	@XmlTransient
	public SClass getSClass() {
		return sClass;
	}
	
	public static void setSClass(SClass sClass) {
		SDownloadResult.sClass = sClass;
	}

	public Object sGet(SField sField) {
		if (sField.getName().equals("projectName")) {
			return getProjectName();
		}
		if (sField.getName().equals("revisionNr")) {
			return getRevisionNr();
		}
		if (sField.getName().equals("file")) {
			return getFile();
		}
		if (sField.getName().equals("serializerOid")) {
			return getSerializerOid();
		}
		if (sField.getName().equals("oid")) {
			return getOid();
		}
		if (sField.getName().equals("rid")) {
			return getRid();
		}
		throw new RuntimeException("Field " + sField.getName() + " not found");
	}

	public void sSet(SField sField, Object val) {
		if (sField.getName().equals("projectName")) {
			setProjectName((String)val);
			return;
		}
		if (sField.getName().equals("revisionNr")) {
			setRevisionNr((Integer)val);
			return;
		}
		if (sField.getName().equals("file")) {
			setFile((DataHandler)val);
			return;
		}
		if (sField.getName().equals("serializerOid")) {
			setSerializerOid((Long)val);
			return;
		}
		if (sField.getName().equals("oid")) {
			setOid((Long)val);
			return;
		}
		if (sField.getName().equals("rid")) {
			setRid((Integer)val);
			return;
		}
		throw new RuntimeException("Field " + sField.getName() + " not found");
	}
	
	public java.lang.String getProjectName() {
		return projectName;
	}

	public void setProjectName(java.lang.String projectName) {
		this.projectName = projectName;
	}
	
	public java.lang.Integer getRevisionNr() {
		return revisionNr;
	}

	public void setRevisionNr(java.lang.Integer revisionNr) {
		this.revisionNr = revisionNr;
	}
	
	public javax.activation.DataHandler getFile() {
		return file;
	}

	public void setFile(javax.activation.DataHandler file) {
		this.file = file;
	}
	
	public long getSerializerOid() {
		return serializerOid;
	}

	public void setSerializerOid(long serializerOid) {
		this.serializerOid = serializerOid;
	}
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + (int) (oid ^ (oid >>> 32));
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		SDownloadResult other = (SDownloadResult) obj;
		if (oid != other.oid)
			return false;
		return true;
	}
}

==> pluginbase-1.5.141.jar: org/bimserver/interfaces/objects/SDownloadResult.java <==
package org.bimserver.interfaces.objects;

/******************************************************************************
 * Copyright (C) 2009-2019  BIMserver.org
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see {@literal<http://www.gnu.org/licenses/>}.
 *****************************************************************************/
import javax.activation.DataHandler;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlTransient;
import org.bimserver.shared.meta.*;
import javax.xml.bind.annotation.XmlRootElement;


@XmlRootElement
@XmlSeeAlso(value={SCheckoutResult.class})
public class SDownloadResult implements SDataBase
{
	private long oid = -1;
	private int rid = 0;

	@XmlTransient
	private static SClass sClass;
	private java.lang.String projectName;
	private java.lang.Integer revisionNr;
	private javax.activation.DataHandler file;
	private long serializerOid;

	public long getOid() {
		return this.oid;
	}

	public void setOid(long oid) {
		this.oid = oid;
	}

	public int getRid() {
		return rid;
	}
	
	public void setRid(int rid) {
		this.rid = rid;
	}
	
	@XmlTransient
	public SClass getSClass() {
		return sClass;
	}
	
	public static void setSClass(SClass sClass) {
		SDownloadResult.sClass = sClass;
	}

	public Object sGet(SField sField) {
		if (sField.getName().equals("projectName")) {
			return getProjectName();
		}
		if (sField.getName().equals("revisionNr")) {
			return getRevisionNr();
		}
		if (sField.getName().equals("file")) {
			return getFile();
		}
		if (sField.getName().equals("serializerOid")) {
			return getSerializerOid();
		}
		if (sField.getName().equals("oid")) {
			return getOid();
		}
		if (sField.getName().equals("rid")) {
			return getRid();
		}
		throw new RuntimeException("Field " + sField.getName() + " not found");
	}

	public void sSet(SField sField, Object val) {
		if (sField.getName().equals("projectName")) {
			setProjectName((String)val);
			return;
		}
		if (sField.getName().equals("revisionNr")) {
			setRevisionNr((Integer)val);
			return;
		}
		if (sField.getName().equals("file")) {
			setFile((DataHandler)val);
			return;
		}
		if (sField.getName().equals("serializerOid")) {
			setSerializerOid((Long)val);
			return;
		}
		if (sField.getName().equals("oid")) {
			setOid((Long)val);
			return;
		}
		if (sField.getName().equals("rid")) {
			setRid((Integer)val);
			return;
		}
		throw new RuntimeException("Field " + sField.getName() + " not found");
	}
	
	public java.lang.String getProjectName() {
		return projectName;
	}

	public void setProjectName(java.lang.String projectName) {
		this.projectName = projectName;
	}
	
	public java.lang.Integer getRevisionNr() {
		return revisionNr;
	}

	public void setRevisionNr(java.lang.Integer revisionNr) {
		this.revisionNr = revisionNr;
	}
	
	public javax.activation.DataHandler getFile() {
		return file;
	}

	public void setFile(javax.activation.DataHandler file) {
		this.file = file;
	}
	
	public long getSerializerOid() {
		return serializerOid;
	}

	public void setSerializerOid(long serializerOid) {
		this.serializerOid = serializerOid;
	}
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + (int) (oid ^ (oid >>> 32));
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		SDownloadResult other = (SDownloadResult) obj;
		if (oid != other.oid)
			return false;
		return true;
	}
}
